@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Frames.py
-Version : 1.5.0
+Version : 1.5.1
 Author  : Stefano Covino
-Date    : 26/08/2011
+Date    : 04/11/2011
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -29,6 +29,7 @@ History : (27/09/2010) First version.
         : (20/11/2010) Better header formatting.
         : (31/12/2010) Minor bug correction.
         : (26/08/2011) Consistency check for unreliable CRVAL1,2 and CDELT1,2.
+        : (04/11/2011) Moer flexibility in header coordinate format.
 """
 
 
@@ -40,6 +41,7 @@ import numpy
 import scipy.optimize as so
 
 import SRP
+from SRP.SRPMath.AstroCoordInput import AstroCoordInput
 from SRP.SRPCatalogue.TWOMASSClass import TWOMASS
 from SRP.SRPCatalogue.USNOClass import USNO
 from SRP.SRPFits.FitsImageClass import FitsImage
@@ -68,11 +70,11 @@ class Astrometry:
                 self.DEC = pcoord.DEC
             else:
                 try:
-                    self.RA = self.FitsFrame.Header[FitsConstants.RA]
-                    self.DEC = self.FitsFrame.Header[FitsConstants.DEC]
+                    heacoord = AstroCoordInput(self.FitsFrame.Header[FitsConstants.RA],self.FitsFrame.Header[FitsConstants.DEC])
                 except KeyError:
-                    self.RA = 0.
-                    self.DEC = 0.
+                    heacoord = AstroCoordInput(0.,0.)
+                self.RA = heacoord.RA
+                self.DEC = heacoord.DEC
             # Pixel reference
             if pixcenter != None:
                 self.CRPIX1 = pixcenter[0]
@@ -146,8 +148,9 @@ class Astrometry:
                 self.CRVAL2 = coord.DEC
             else:
                 try:
-                    self.CRVAL1 = self.FitsFrame.Header[FitsConstants.CRVAL1]
-                    self.CRVAL2 = self.FitsFrame.Header[FitsConstants.CRVAL2]
+                    heacoord = AstroCoordInput(self.FitsFrame.Header[FitsConstants.CRVAL1],self.FitsFrame.Header[FitsConstants.CRVAL2])
+                    self.CRVAL1 = heacoord.RA
+                    self.CRVAL2 = heacoord.DEC
                 except KeyError:
                     self.CRVAL1 = self.RA
                     self.CRVAL2 = self.DEC
