@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : SRP
-Version : 1.0.36
+Version : 1.0.41
 Author  : Stefano Covino
-Date    : 30/10/2011
+Date    : 16/12/2011
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -53,6 +53,11 @@ History : (28/09/2010) First named version.
         : (12/10/2011) V. 3.10.2b1.
         : (23/10/2011) V. 3.10.2b2.
         : (30/10/2011) V. 3.10.2.
+        : (03/11/2011) V. 3.10.3b1.
+        : (04/11/2011) V. 3.10.3b2.
+        : (15/11/2011) V. 3.10.3b3.
+        : (10/12/2011) V. 3.10.3b4.
+        : (16/12/2011) V. 3.10.3.
 """
 
 
@@ -63,5 +68,5 @@ __all__ = ['SRPCatalogue','SRPFits','SRPFrames','SRPMath','SRPNet','SRPSpectrosc
 
 
 # Version
-__version__ = '3.10.2'
+__version__ = '3.10.3'
 
